@@ -18,13 +18,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "config_gui.h"
-#include "devperf.h"
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include "config_gui.h"
+#include "devperf.h"
+
 #include <gtk/gtk.h>
 #include <libxfce4panel/libxfce4panel.h>
 #include <libxfce4ui/libxfce4ui.h>
@@ -82,7 +82,7 @@ typedef enum monitor_bar_order_t {
 typedef struct param_t {
     /* Configurable parameters */
     char            acDevice[128];
-#if  !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__)
+#if  !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__) && !defined(__APPLE__)
     dev_t           st_rdev;
 #endif
     int             fTitleDisplayed;
@@ -163,7 +163,7 @@ static int DisplayPerf (struct diskperf_t *poPlugin)
     struct devperf_t  oPerf;
     struct param_t   *poConf = &poPlugin->oConf.oParam;
     struct monitor_t *poMonitor = &poPlugin->oMonitor;
-#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__)
+#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__) && !defined(__APPLE__)
     struct stat       oStat;
 #endif
     uint64_t        iInterval_ns, rbytes, wbytes, iRBusy_ns, iWBusy_ns;
@@ -175,7 +175,7 @@ static int DisplayPerf (struct diskperf_t *poPlugin)
     rbytes = wbytes = iRBusy_ns = iWBusy_ns = -1;
     memset (&oPerf, 0, sizeof (oPerf));
     oPerf.qlen = -1;
-#if defined(__FreeBSD__) || defined (__NetBSD__) || defined(__OpenBSD__) || defined(__sun__)
+#if defined(__FreeBSD__) || defined (__NetBSD__) || defined(__OpenBSD__) || defined(__sun__) || defined(__APPLE__)
     status = DevGetPerfData (poConf->acDevice, &oPerf);
 #else
     if (poConf->st_rdev == 0)
@@ -309,11 +309,7 @@ static int SetSingleBarColor (struct diskperf_t *p_poPlugin, int p_iBar)
     Widget_t          *pwBar;
 
     pwBar = poMonitor->aoPerfBar[p_iBar].pwBar;
-#if GTK_CHECK_VERSION (3, 20, 0)
     css = g_strdup_printf("progressbar progress { background-color: %s; background-image: none; }",
-#else
-    css = g_strdup_printf(".progressbar progress { background-color: %s; background-image: none; }",
-#endif
                                   gdk_rgba_to_string(&poConf->aoColor[p_iBar]));
     /* Setup Gtk style */
     DBG("setting css to %s for bar %d", css, p_iBar);
@@ -400,19 +396,11 @@ static int CreateMonitorBars (struct diskperf_t *poPlugin, GtkOrientation p_iOri
         gtk_orientable_set_orientation (GTK_ORIENTABLE(*pwBar), !p_iOrientation);
         gtk_progress_bar_set_inverted (GTK_PROGRESS_BAR(*pwBar), p_iOrientation == GTK_ORIENTATION_HORIZONTAL);
         css_provider = gtk_css_provider_new ();
-#if GTK_CHECK_VERSION (3, 20, 0)
         gtk_css_provider_load_from_data (css_provider, "\
             progressbar.horizontal trough { min-height: 4px; }\
             progressbar.horizontal progress { min-height: 4px; }\
             progressbar.vertical trough { min-width: 4px; }\
             progressbar.vertical progress { min-width: 4px; }",
-#else
-        gtk_css_provider_load_from_data (css_provider, "\
-            .progressbar.horizontal trough { min-height: 4px; }\
-            .progressbar.horizontal progress { min-height: 4px; }\
-            .progressbar.vertical trough { min-width: 4px; }\
-            .progressbar.vertical progress { min-width: 4px; }",
-#endif
             -1, NULL);
         gtk_style_context_add_provider (
             GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (*pwBar))),
@@ -440,7 +428,7 @@ static diskperf_t *diskperf_create_control (XfcePanelPlugin *plugin)
     struct diskperf_t *poPlugin;
     struct param_t *poConf;
     struct monitor_t *poMonitor;
-#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__)
+#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__) && !defined(__APPLE__)
     struct stat     oStat;
     int             status;
 #endif
@@ -461,6 +449,9 @@ static diskperf_t *diskperf_create_control (XfcePanelPlugin *plugin)
 #elif defined(__sun__)
     strncpy (poConf->acDevice, "sd0", 128);
     strncpy (poConf->acTitle, "sd0", 16);
+#elif defined(__APPLE__)
+    strncpy (poConf->acDevice, "disk0", 128);
+    strncpy (poConf->acTitle, "disk0", 16);
 #else
     strncpy (poConf->acDevice, "/dev/sda", 128);
     status = stat (poConf->acDevice, &oStat);
@@ -525,7 +516,7 @@ static void diskperf_read_config (XfcePanelPlugin *plugin,
     struct param_t *poConf = &poPlugin->oConf.oParam;
     struct monitor_t *poMonitor = &poPlugin->oMonitor;
     Widget_t       *pw2ndBar = poPlugin->oMonitor.awProgressBar + 1;
-#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__)
+#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__) && !defined(__APPLE__)
     struct stat     oStat;
     int             status;
 #endif
@@ -542,7 +533,7 @@ static void diskperf_read_config (XfcePanelPlugin *plugin,
     if ((value = xfce_rc_read_entry (rc, (CONF_DEVICE), NULL))) {
         memset (poConf->acDevice, 0, sizeof (poConf->acDevice));
         strncpy (poConf->acDevice, value, sizeof (poConf->acDevice) - 1);
-#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__)
+#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__) && !defined(__APPLE__)
         status = stat (poConf->acDevice, &oStat);
         poConf->st_rdev = (status == -1 ? 0 : oStat.st_rdev);
 #endif
@@ -645,7 +636,7 @@ static void SetDevice (Widget_t p_wTF, void *p_pvPlugin)
     struct diskperf_t *poPlugin = (diskperf_t *) p_pvPlugin;
     struct param_t    *poConf = &poPlugin->oConf.oParam;
     const char        *pcDevice = gtk_entry_get_text (GTK_ENTRY (p_wTF));
-#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__)
+#if !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__) && !defined(__APPLE__)
     struct stat oStat;
 
     stat (pcDevice, &oStat);
@@ -865,20 +856,16 @@ static void About (Widget_t w, void *unused)
         "Roger Seguin <roger_seguin@msn.com>",
         NULL
     };
-    GdkPixbuf *icon;
 
-    icon = xfce_panel_pixbuf_from_source("drive-harddisk", NULL, 32);
     gtk_show_about_dialog(NULL,
-        "logo", icon,
+        "logo-icon-name", "drive-harddisk",
         "license", xfce_get_license_text (XFCE_LICENSE_TEXT_BSD),
         "version", PACKAGE_VERSION,
         "program-name", PACKAGE_NAME,
         "comments", _("Diskperf monitor displays instantaneous disk I/O transfer rates and busy times"),
         "website", "https://docs.xfce.org/panel-plugins/xfce4-diskperf-plugin",
-        "copyright", _("Copyright (c) 2003, 2004 Roger Seguin"),
+        "copyright", "Copyright \302\251 2003-2024 The Xfce development team",
         "authors", auth, NULL);
-    if(icon)
-        g_object_unref(G_OBJECT(icon));
 }
 
 static void diskperf_dialog_response (GtkWidget *dlg, int response, 
@@ -906,10 +893,10 @@ static void diskperf_create_options (XfcePanelPlugin *plugin,
 
     xfce_panel_plugin_block_menu (plugin);
     
-    dlg = xfce_titled_dialog_new_with_buttons (_("Disk Performance Monitor"),
+    dlg = xfce_titled_dialog_new_with_mixed_buttons (_("Disk Performance Monitor"),
                                                GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
                                                GTK_DIALOG_DESTROY_WITH_PARENT,
-                                               "gtk-close", GTK_RESPONSE_OK,
+                                               "window-close-symbolic", _("_Close"), GTK_RESPONSE_OK,
                                                NULL);
 
     gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
